Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/sys splimp() -> splvm() (mbufs are "memory allocation")



details:   https://anonhg.NetBSD.org/src/rev/a63844d12cd1
branches:  trunk
changeset: 502224:a63844d12cd1
user:      thorpej <thorpej%NetBSD.org@localhost>
date:      Sun Jan 14 02:07:22 2001 +0000

description:
splimp() -> splvm() (mbufs are "memory allocation")

diffstat:

 sys/sys/mbuf.h |  6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diffs (27 lines):

diff -r 7712608b99f0 -r a63844d12cd1 sys/sys/mbuf.h
--- a/sys/sys/mbuf.h    Sun Jan 14 02:06:21 2001 +0000
+++ b/sys/sys/mbuf.h    Sun Jan 14 02:07:22 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: mbuf.h,v 1.55 2000/12/02 03:03:14 itojun Exp $ */
+/*     $NetBSD: mbuf.h,v 1.56 2001/01/14 02:07:22 thorpej Exp $        */
 
 /*-
  * Copyright (c) 1996, 1997, 1999 The NetBSD Foundation, Inc.
@@ -206,7 +206,7 @@
  * drivers.
  */
 #define        MBUFLOCK(code) \
-       do { int ms = splimp(); \
+       do { int ms = splvm(); \
          { code } \
          splx(ms); \
        } while (0)
@@ -254,7 +254,7 @@
 /*
  * Macros for tracking external storage associated with an mbuf.
  *
  * Note: add and delete reference must be called at splimp().
  */
 #ifdef DEBUG
 #define MCLREFDEBUGN(m, file, line) do {                               \
@@ -254,7 +254,7 @@
  * Macros for tracking external storage associated with an mbuf.
  *
- * Note: add and delete reference must be called at splimp().
+ * Note: add and delete reference must be called at splvm().
  */
 #ifdef DEBUG



Home | Main Index | Thread Index | Old Index